@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2024 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -144,6 +144,13 @@ bool SqlEngine::applySqlFile(const QString sqlFile) {
 }
 
 
+QDateTime parseDateIgnoreTime(QString dateStr) {
+    QDateTime dateTime = QDateTime::fromString(dateStr, Qt::DateFormat::ISODate);
+    dateTime.setOffsetFromUtc(0);
+    return dateTime;
+}
+
+
 void SqlEngine::addConferenceToDB(QHash<QString,QString> &aConference, int conferenceId, bool omit_display_time_shift) {
     QSqlQuery query(db);
     bool insert = conferenceId <= 0;
@@ -162,8 +169,8 @@ void SqlEngine::addConferenceToDB(QHash<QString,QString> &aConference, int confe
     foreach (QString prop_name, (QList<QString>() << "title" << "url" << "subtitle" << "venue" << "city")) {
         query.bindValue(QString(":") + prop_name, aConference[prop_name]);
     }
-    query.bindValue(":start", QDateTime(QDate::fromString(aConference["start"],DATE_FORMAT),QTime(0,0),Qt::UTC).toTime_t());
-    query.bindValue(":end", QDateTime(QDate::fromString(aConference["end"],DATE_FORMAT),QTime(0,0),Qt::UTC).toTime_t());
+    query.bindValue(":start", parseDateIgnoreTime(aConference["start"]).toTime_t());
+    query.bindValue(":end", parseDateIgnoreTime(aConference["end"]).toTime_t());
     QTime dayChange = QTime::fromString(aConference["day_change"].left(TIME_FORMAT.size()), TIME_FORMAT);
     query.bindValue(":day_change", QTime(0, 0).secsTo(dayChange));
     query.bindValue(":timeslot_duration", -QTime::fromString(aConference["timeslot_duration"],TIME_FORMAT).secsTo(QTime(0,0)));
@@ -452,6 +459,42 @@ bool SqlEngine::deleteConference(int id) {
 }
 
 
+bool SqlEngine::deleteStaleEvents(int conferenceId, QSet<QString> eventIdsToKeep) {
+    QSqlQuery query(db);
+
+    // get all event IDs from conference
+    query.prepare("SELECT id FROM event WHERE xid_conference = ?");
+    query.bindValue(0, conferenceId);
+    bool success = query.exec();
+    emitSqlQueryError(query);
+    if (!success) return false;
+    QSet<QString> existingEventIds;
+    while (query.next()) existingEventIds.insert(query.value(0).toString());
+
+    // determine events that are not existing anymore
+    QSet<QString> eventIdsToRemove = existingEventIds.subtract(eventIdsToKeep);
+
+    // delete events including entries from referencing tables
+    QList<QString> tables = {"link", "event_room", "event_person"};
+    for(const QString& eventId: eventIdsToRemove) {
+        for(const QString& table: tables) {
+            query.prepare(QString("DELETE FROM %1 WHERE xid_conference = ? AND xid_event = ?").arg(table));
+            query.bindValue(0, conferenceId);
+            query.bindValue(1, eventId);
+            success &= query.exec();
+            emitSqlQueryError(query);
+        }
+        query.prepare("DELETE FROM event WHERE xid_conference = ? AND id = ?");
+        query.bindValue(0, conferenceId);
+        query.bindValue(1, eventId);
+        success &= query.exec();
+        emitSqlQueryError(query);
+    }
+
+    return success;
+}
+
+
 void SqlEngine::emitSqlQueryError(const QSqlQuery &query) {
     QSqlError error = query.lastError();
     if (error.type() == QSqlError::NoError) return;
